==> tweedsuit_0.7.8-2.tar.gz: tweedsuit-0.7.8/src/TweedUI/js/tweedscripts.js <==
Qt.include("OAuth.js");
Qt.include("helpers.js");
/*
    Send tweets (and dm's)
*/
var cols;
var loadedcols = [];
var twitterusername = "";

function populateLoadedcols(a) {
    for (var i = 0; i < a; i++) {
        loadedcols[i] = false;
    }
}

function sendDM(tweet) {
    if (tweet.substring(0,3) != "D @" && tweet.substring(0,3) != "d @") {
        return false;
    }
    var content = tweet;
    var splt = content.split(" ");
    var user = splt[1].substring(1);
    console.log("user: " + user);
    if (user.length < 1) return false;
    if (oauth.authorized) {
        var params = [["screen_name", user]]
        // var body1 = "status=" + encodeURIComponent(content);
        var bodylength = "status=" + content;
        var body = "text=" + url_encode(content.substring(3+user.length));
        var xhr = createOAuthHeader("POST", "https://api.twitter.com/1/direct_messages/new.json", undefined, {"token":oauth.token, "secret":oauth.secret}, params,body);
        xhr.onreadystatechange = function() {
            if (xhr.readyState == XMLHttpRequest.DONE) {
               //console.log("received: " + xhr.responseText);
               console.log("status: " + xhr.status);
               // console.log("status text: " + xhr.statusText);

            }
        }
        xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        //xhr.setRequestHeader("Content-length", bodylength.length);
        xhr.setRequestHeader("Accept-Language", "en");
        xhr.send(body);
    }
}

function sendTweet(tweet, params) {
//    var content = utf8Encode(tweet);
    if (tweet.substring(0,3) == "D @" || tweet.substring(0,3) == "d @") {
        console.log("dm");
        sendDM(tweet);
        return;
    }
    var content = tweet;
    if (oauth.authorized) {
        // var params = [["status", escape(content)]]
        // var body1 = "status=" + encodeURIComponent(content);
        var bodylength = "status=" + content;
        var body = "status=" + url_encode(content);
        // console.log("converted: " + body);

        // OAuthLogic.createOAuthHeader("POST", "https://api.twitter.com/oauth/access_token", [["oauth_verifier",pin]], {"token":token,"secret":secret});
        var xhr = createOAuthHeader("POST", "https://api.twitter.com/1/statuses/update.json", undefined, {"token":oauth.token, "secret":oauth.secret}, params,body);
        xhr.onreadystatechange = function() {
            if (xhr.readyState == XMLHttpRequest.DONE) {
               //console.log("received: " + xhr.responseText);
               console.log("status: " + xhr.status);
               // console.log("status text: " + xhr.statusText);

            }
        }
        xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        xhr.setRequestHeader("Content-length", bodylength.length);
        xhr.setRequestHeader("Accept-Language", "en");
        xhr.send(body);
    }
}

function follow(username) {
    var user = username;
    if (oauth.authorized) {
        // var params = [["status", escape(content)]]
        // var body1 = "status=" + encodeURIComponent(content);
        var body = "";
        var params = [["screen_name", user], ["follow", "true"]];
        // console.log("converted: " + body);

        // OAuthLogic.createOAuthHeader("POST", "https://api.twitter.com/oauth/access_token", [["oauth_verifier",pin]], {"token":token,"secret":secret});
        var xhr = createOAuthHeader("POST", "https://api.twitter.com/1/friendships/create.xml", undefined, {"token":oauth.token, "secret":oauth.secret}, params);
        xhr.onreadystatechange = function() {
            if (xhr.readyState == XMLHttpRequest.DONE) {
               //console.log("received: " + xhr.responseText);
               console.log("status: " + xhr.status);
               // console.log("status text: " + xhr.statusText);

            }
        }
        xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        xhr.setRequestHeader("Accept-Language", "en");
        xhr.send(body);
    }
}

function unFollow(username) {
    var user = username;
    if (oauth.authorized) {
        // var params = [["status", escape(content)]]
        // var body1 = "status=" + encodeURIComponent(content);
        var body = "";
        var params = [["screen_name", user]];
        // console.log("converted: " + body);

        // OAuthLogic.createOAuthHeader("POST", "https://api.twitter.com/oauth/access_token", [["oauth_verifier",pin]], {"token":token,"secret":secret});
        var xhr = createOAuthHeader("POST", "https://api.twitter.com/1/friendships/destroy.xml", undefined, {"token":oauth.token, "secret":oauth.secret}, params);
        xhr.onreadystatechange = function() {
            if (xhr.readyState == XMLHttpRequest.DONE) {
               //console.log("received: " + xhr.responseText);
               console.log("status: " + xhr.status);
               // console.log("status text: " + xhr.statusText);

            }
        }
        xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        xhr.setRequestHeader("Accept-Language", "en");
        xhr.send(body);
    }
}
/*
    view an image preview
*/

var viewimagecomponent
var viewimageobject
var imgsrc
function viewImage(source) {
    imgsrc = source
    viewimagecomponent = Qt.createComponent("ViewImage.qml");
    console.log("viewimage")
    if (viewimagecomponent.status == Component.Ready) {
        console.log("ready fast")
        finishViewImage();
    } else {
        console.log("ready slow")
        viewimagecomponent.statusChanged.connect(finishViewImage);

    }
}

function finishViewImage() {
    console.log("status changed")
    if (viewimagecomponent.status == Component.Ready) {
        console.log("status ready")
        viewimageobject = viewimagecomponent.createObject(screen);
        if ( viewimageobject == null) {
            console.log("ERROR")
        } else {
            viewimageobject.imgSource = imgsrc;
        }
    } else if (viewimagecomponent.status == Component.Error) {
        // Error Handling
        console.log("Error loading component:", viewimagecomponent.errorString());
    }
}

/*
    Shortening urls
*/

function shortenUrl(post, shortener) {
    // this._regExp = /https?:\/\/[^ \n\t]+/g;
    var newtest = post;
    var foundUrls = post.match(/https?:\/\/[^ \n\t]+/g);
    console.log(foundUrls);
    var xhrs = [];
    var url = [];
    var ready = [];
    for (var i = 0; i < foundUrls.length; i++) {
        if (shortener == "met.al") {
            replaceUrl("http://met.al/yourls-api.php?action=shorturl&url=" + url_encode(foundUrls[i]) + "&format=json", foundUrls[i], shortener);
        } else if (shortener == "is.gd") {
            replaceUrl("http://is.gd/create.php?url=" + url_encode(foundUrls[i]) + "&format=simple", foundUrls[i], shortener);
        }
    }
    return post;
}

function replaceUrl(fetchurl, oldurl, shortener) {
    var xhrs = new XMLHttpRequest;
    console.log("fetchurl = " + fetchurl);
    xhrs.open("GET", fetchurl);
    xhrs.onreadystatechange = function() {
        // console.log("ok.. state changed.");
        if (xhrs.readyState == XMLHttpRequest.DONE) {

            console.log("received: " + xhrs.responseText);
            console.log("shortening done: status: " + xhrs.status);
            var shorturl = "";
            if (shortener == "met.al") {
                var jsonrep = eval("(" + xhrs.responseText + ")");
                shorturl = jsonrep.shorturl;
            } else if (shortener == "is.gd") {
                shorturl = xhrs.responseText.trim();
            } else return;
            if (shorturl.length > 0) tweetBox.tweetText = tweetBox.tweetText.replace(oldurl, shorturl);
        }
    }
    xhrs.send();
}

function getTranslateUrl(text, toLang) {
    console.log("getting translate url");
    var tgLang = (toLang)?toLang:"en";
    return "https://www.googleapis.com/language/translate/v2?key=AIzaSyDr7vpeo3JXRzsZTsZ6Bh03eHN_YFQRBFc&target=en&q=" + url_encode(text);
}

function getTranslatedText(xhrz) {

    if (xhrz.readyState == XMLHttpRequest.DONE) {
        var j = eval("(" + xhrz.responseText + ")");
        if (j.data.translations.length > 0) {
            return j.data.translations[0].translatedText;
        } else return false
    } else {
        return false
    }
}

==> tweedsuit_0.8.0-3.tar.gz: tweedsuit-0.8.0/src/TweedUI/js/tweedscripts.js <==
Qt.include("OAuth.js");
Qt.include("helpers.js");
/*
    Send tweets (and dm's)
*/
var cols;
var loadedcols = [];
var twitterusername = "";
var translang = "en";
function populateLoadedcols(a) {
    for (var i = 0; i < a; i++) {
        loadedcols[i] = false;
    }
}

function sendDM(tweet) {
    if (tweet.substring(0,3) != "D @" && tweet.substring(0,3) != "d @") {
        return false;
    }
    var content = tweet;
    var splt = content.split(" ");
    var user = splt[1].substring(1);
    console.log("user: " + user);
    if (user.length < 1) return false;
    if (oauth.authorized) {
        var params = [["screen_name", user]]
        // var body1 = "status=" + encodeURIComponent(content);
        var bodylength = "status=" + content;
        var body = "text=" + url_encode(content.substring(3+user.length));
        var xhr = createOAuthHeader("POST", "https://api.twitter.com/1/direct_messages/new.json", undefined, {"token":oauth.token, "secret":oauth.secret}, params,body);
        xhr.onreadystatechange = function() {
            if (xhr.readyState == XMLHttpRequest.DONE) {
               //console.log("received: " + xhr.responseText);
               console.log("status: " + xhr.status);
               // console.log("status text: " + xhr.statusText);

            }
        }
        xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        //xhr.setRequestHeader("Content-length", bodylength.length);
        xhr.setRequestHeader("Accept-Language", "en");
        xhr.send(body);
    }
}

function sendTweet(tweet, params) {
//    var content = utf8Encode(tweet);
    if (tweet.substring(0,3) == "D @" || tweet.substring(0,3) == "d @") {
        console.log("dm");
        sendDM(tweet);
        return;
    }
    var content = tweet;
    if (oauth.authorized) {
        // var params = [["status", escape(content)]]
        // var body1 = "status=" + encodeURIComponent(content);
        var bodylength = "status=" + content;
        var body = "status=" + url_encode(content);
        // console.log("converted: " + body);

        // OAuthLogic.createOAuthHeader("POST", "https://api.twitter.com/oauth/access_token", [["oauth_verifier",pin]], {"token":token,"secret":secret});
        var xhr = createOAuthHeader("POST", "https://api.twitter.com/1/statuses/update.json", undefined, {"token":oauth.token, "secret":oauth.secret}, params,body);
        xhr.onreadystatechange = function() {
            if (xhr.readyState == XMLHttpRequest.DONE) {
               //console.log("received: " + xhr.responseText);
               console.log("status: " + xhr.status);
               // console.log("status text: " + xhr.statusText);

            }
        }
        xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        xhr.setRequestHeader("Content-length", bodylength.length);
        xhr.setRequestHeader("Accept-Language", "en");
        xhr.send(body);
    }
}

function follow(username) {
    var user = username;
    if (oauth.authorized) {
        // var params = [["status", escape(content)]]
        // var body1 = "status=" + encodeURIComponent(content);
        var body = "";
        var params = [["screen_name", user], ["follow", "true"]];
        // console.log("converted: " + body);

        // OAuthLogic.createOAuthHeader("POST", "https://api.twitter.com/oauth/access_token", [["oauth_verifier",pin]], {"token":token,"secret":secret});
        var xhr = createOAuthHeader("POST", "https://api.twitter.com/1/friendships/create.xml", undefined, {"token":oauth.token, "secret":oauth.secret}, params);
        xhr.onreadystatechange = function() {
            if (xhr.readyState == XMLHttpRequest.DONE) {
               //console.log("received: " + xhr.responseText);
               console.log("status: " + xhr.status);
               // console.log("status text: " + xhr.statusText);

            }
        }
        xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        xhr.setRequestHeader("Accept-Language", "en");
        xhr.send(body);
    }
}

function unFollow(username) {
    var user = username;
    if (oauth.authorized) {
        // var params = [["status", escape(content)]]
        // var body1 = "status=" + encodeURIComponent(content);
        var body = "";
        var params = [["screen_name", user]];
        // console.log("converted: " + body);

        // OAuthLogic.createOAuthHeader("POST", "https://api.twitter.com/oauth/access_token", [["oauth_verifier",pin]], {"token":token,"secret":secret});
        var xhr = createOAuthHeader("POST", "https://api.twitter.com/1/friendships/destroy.xml", undefined, {"token":oauth.token, "secret":oauth.secret}, params);
        xhr.onreadystatechange = function() {
            if (xhr.readyState == XMLHttpRequest.DONE) {
               //console.log("received: " + xhr.responseText);
               console.log("status: " + xhr.status);
               // console.log("status text: " + xhr.statusText);

            }
        }
        xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        xhr.setRequestHeader("Accept-Language", "en");
        xhr.send(body);
    }
}
/*
    view an image preview
*/

var viewimagecomponent
var viewimageobject
var imgsrc
function viewImage(source) {
    imgsrc = source
    viewimagecomponent = Qt.createComponent("ViewImage.qml");
    console.log("viewimage")
    if (viewimagecomponent.status == Component.Ready) {
        console.log("ready fast")
        finishViewImage();
    } else {
        console.log("ready slow")
        viewimagecomponent.statusChanged.connect(finishViewImage);

    }
}

function finishViewImage() {
    console.log("status changed")
    if (viewimagecomponent.status == Component.Ready) {
        console.log("status ready")
        viewimageobject = viewimagecomponent.createObject(screen);
        if ( viewimageobject == null) {
            console.log("ERROR")
        } else {
            viewimageobject.imgSource = imgsrc;
        }
    } else if (viewimagecomponent.status == Component.Error) {
        // Error Handling
        console.log("Error loading component:", viewimagecomponent.errorString());
    }
}

/*
    Shortening urls
*/

function shortenUrl(post, shortener) {
    // this._regExp = /https?:\/\/[^ \n\t]+/g;
    var newtest = post;
    var foundUrls = post.match(/https?:\/\/[^ \n\t]+/g);
    console.log(foundUrls);
    var xhrs = [];
    var url = [];
    var ready = [];
    for (var i = 0; i < foundUrls.length; i++) {
        if (shortener == "met.al") {
            replaceUrl("http://met.al/yourls-api.php?action=shorturl&url=" + url_encode(foundUrls[i]) + "&format=json", foundUrls[i], shortener);
        } else if (shortener == "is.gd") {
            replaceUrl("http://is.gd/create.php?url=" + url_encode(foundUrls[i]) + "&format=simple", foundUrls[i], shortener);
        }
    }
    return post;
}

function replaceUrl(fetchurl, oldurl, shortener) {
    var xhrs = new XMLHttpRequest;
    console.log("fetchurl = " + fetchurl);
    xhrs.open("GET", fetchurl);
    xhrs.onreadystatechange = function() {
        // console.log("ok.. state changed.");
        if (xhrs.readyState == XMLHttpRequest.DONE) {

            console.log("received: " + xhrs.responseText);
            console.log("shortening done: status: " + xhrs.status);
            var shorturl = "";
            if (shortener == "met.al") {
                var jsonrep = eval("(" + xhrs.responseText + ")");
                shorturl = jsonrep.shorturl;
            } else if (shortener == "is.gd") {
                shorturl = xhrs.responseText.trim();
            } else return;
            if (shorturl.length > 0) tweetBox.tweetText = tweetBox.tweetText.replace(oldurl, shorturl);
        }
    }
    xhrs.send();
}

function getTranslateUrl(text, toLang) {
    console.log("getting translate url");
    console.log("translang: " + translang)
    var ret = "https://www.googleapis.com/language/translate/v2?key=AIzaSyDr7vpeo3JXRzsZTsZ6Bh03eHN_YFQRBFc&target=" + translang + "&q=" + url_encode(text);
    // console.log(ret)
    return ret
}

function getTranslatedText(xhrz) {

    if (xhrz.readyState == XMLHttpRequest.DONE) {
        /* console.log(xhrz.status);
        console.log(xhrz.responseText); */

        var j = eval("(" + xhrz.responseText + ")");
        if (j.data.translations.length > 0) {
            return j.data.translations[0].translatedText;
        } else return false
    } else {
        return false
    }
}

function getLangList() {
    var langs = [
    {
     "language": "af",
     "name": "Afrikaans"
    },
    {
     "language": "sq",
     "name": "Albanian"
    },
    {
     "language": "ar",
     "name": "Arabic"
    },
    {
     "language": "hy",
     "name": "Armenian"
    },
    {
     "language": "az",
     "name": "Azerbaijani"
    },
    {
     "language": "eu",
     "name": "Basque"
    },
    {
     "language": "be",
     "name": "Belarusian"
    },
    {
     "language": "bn",
     "name": "Bengali"
    },
    {
     "language": "bg",
     "name": "Bulgarian"
    },
    {
     "language": "ca",
     "name": "Catalan"
    },
    {
     "language": "zh",
     "name": "Chinese (Simplified)"
    },
    {
     "language": "zh-TW",
     "name": "Chinese (Traditional)"
    },
    {
     "language": "hr",
     "name": "Croatian"
    },
    {
     "language": "cs",
     "name": "Czech"
    },
    {
     "language": "da",
     "name": "Danish"
    },
    {
     "language": "nl",
     "name": "Dutch"
    },
    {
     "language": "en",
     "name": "English"
    },
    {
     "language": "et",
     "name": "Estonian"
    },
    {
     "language": "tl",
     "name": "Filipino"
    },
    {
     "language": "fi",
     "name": "Finnish"
    },
    {
     "language": "fr",
     "name": "French"
    },
    {
     "language": "gl",
     "name": "Galician"
    },
    {
     "language": "ka",
     "name": "Georgian"
    },
    {
     "language": "de",
     "name": "German"
    },
    {
     "language": "el",
     "name": "Greek"
    },
    {
     "language": "gu",
     "name": "Gujarati"
    },
    {
     "language": "ht",
     "name": "Haitian Creole"
    },
    {
     "language": "iw",
     "name": "Hebrew"
    },
    {
     "language": "hi",
     "name": "Hindi"
    },
    {
     "language": "hu",
     "name": "Hungarian"
    },
    {
     "language": "is",
     "name": "Icelandic"
    },
    {
     "language": "id",
     "name": "Indonesian"
    },
    {
     "language": "ga",
     "name": "Irish"
    },
    {
     "language": "it",
     "name": "Italian"
    },
    {
     "language": "ja",
     "name": "Japanese"
    },
    {
     "language": "kn",
     "name": "Kannada"
    },
    {
     "language": "ko",
     "name": "Korean"
    },
    {
     "language": "la",
     "name": "Latin"
    },
    {
     "language": "lv",
     "name": "Latvian"
    },
    {
     "language": "lt",
     "name": "Lithuanian"
    },
    {
     "language": "mk",
     "name": "Macedonian"
    },
    {
     "language": "ms",
     "name": "Malay"
    },
    {
     "language": "mt",
     "name": "Maltese"
    },
    {
     "language": "no",
     "name": "Norwegian"
    },
    {
     "language": "fa",
     "name": "Persian"
    },
    {
     "language": "pl",
     "name": "Polish"
    },
    {
     "language": "pt",
     "name": "Portuguese"
    },
    {
     "language": "ro",
     "name": "Romanian"
    },
    {
     "language": "ru",
     "name": "Russian"
    },
    {
     "language": "sr",
     "name": "Serbian"
    },
    {
     "language": "sk",
     "name": "Slovak"
    },
    {
     "language": "sl",
     "name": "Slovenian"
    },
    {
     "language": "es",
     "name": "Spanish"
    },
    {
     "language": "sw",
     "name": "Swahili"
    },
    {
     "language": "sv",
     "name": "Swedish"
    },
    {
     "language": "ta",
     "name": "Tamil"
    },
    {
     "language": "te",
     "name": "Telugu"
    },
    {
     "language": "th",
     "name": "Thai"
    },
    {
     "language": "tr",
     "name": "Turkish"
    },
    {
     "language": "uk",
     "name": "Ukrainian"
    },
    {
     "language": "ur",
     "name": "Urdu"
    },
    {
     "language": "vi",
     "name": "Vietnamese"
    },
    {
     "language": "cy",
     "name": "Welsh"
    },
    {
     "language": "yi",
     "name": "Yiddish"
    }
    ];
    return langs;
}
function getLangName(lang) {
    var langs = getLangList();
    for (var i = 0; i < langs.length; i++) {
        if (langs[i].language == lang) {
            return langs[i].name;
        }
    }
}

function getLangSetting() {
    var lang = storage.getSetting("lang");
    if (lang === null) {
        lang = "en";
    }
    return lang;
}
